package VMOMI::EventFilterSpecRecursionOption;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
